## $Id: studycourse.py 7304 2011-12-07 08:53:50Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Container which holds the data of the student study courses
and contains the (student) study level objects.
"""
import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.sirp.students.interfaces import (
    IStudentStudyCourse, IStudentNavigation, IStudentStudyLevel)
from waeup.sirp.students.studylevel import CourseTicket
from waeup.sirp.utils.helpers import attrs_to_fields

class StudentStudyCourse(grok.Container):
    """This is a container for study levels.
    """
    grok.implements(IStudentStudyCourse, IStudentNavigation)
    grok.provides(IStudentStudyCourse)

    def __init__(self):
        super(StudentStudyCourse, self).__init__()
        return

    def getStudent(self):
        return self.__parent__

    def addStudentStudyLevel(self, cert, studylevel):
        """Add a study level object.
        """
        if not IStudentStudyLevel.providedBy(studylevel):
            raise TypeError(
                'StudentStudyCourses contain only IStudentStudyLevel instances')
        self[str(studylevel.level)] = studylevel

        #Create course tickets automatically
        for key, val in cert.items():
            if val.level != studylevel.level:
                continue
            ticket = CourseTicket()
            ticket.code = val.getCourseCode()
            ticket.automatic = True
            ticket.core_or_elective = val.core_or_elective
            ticket.title = val.course.title
            ticket.faculty = val.course.__parent__.__parent__.__parent__.title
            ticket.department = val.course.__parent__.__parent__.title
            ticket.fcode = val.course.__parent__.__parent__.__parent__.code
            ticket.dcode = val.course.__parent__.__parent__.code
            ticket.credits = val.course.credits
            ticket.passmark = val.course.passmark
            ticket.semester = val.course.semester
            self[str(studylevel.level)][val.getCourseCode()] = ticket
        return

StudentStudyCourse = attrs_to_fields(StudentStudyCourse)

class StudentStudyCourseFactory(grok.GlobalUtility):
    """A factory for students.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.StudentStudyCourse')
    title = u"Create a new student study course.",
    description = u"This factory instantiates new student study course instances."

    def __call__(self, *args, **kw):
        return StudentStudyCourse()

    def getInterfaces(self):
        return implementedBy(StudentStudyCourse)